@@ -12,9 +12,9 @@ test_that("Converts values accurately", {
 })
 
 test_that("Yields correct columns and rows", {
-  expect_equal(colnames(x), c("rowname", colnames(y)))
+  expect_equal(colnames(x), c("term", colnames(y)))
   expect_equal(nrow(x), ncol(y))
-  expect_equal(x$rowname, colnames(y))
+  expect_equal(x$term, colnames(y))
   expect_equal(rownames(y), colnames(y))
 })
 
@@ -25,4 +25,4 @@ test_that("Diagonal sets correctly", {
 
 test_that("as_matrix preservers diag from correlate", {
   expect_equal(diag(as.matrix(x[-1])), unname(diag(y)))
-})
\ No newline at end of file
+})
