@@ -72,5 +72,5 @@ test_that("Vectors and padding", {
 })
 
 test_that("Fashion works against matrix", {
-  expect_is(fashion(as.matrix(correlate(mtcars))), "data.frame")
+  expect_s3_class(fashion(as.matrix(correlate(mtcars))), "data.frame")
 })
