@@ -4,7 +4,7 @@ d <- datasets::iris[, 1:4]
 d[1, 1] <- NA
 
 remote_mtcars <- mtcars
-class(remote_mtcars) <- c(class(remote_mtcars), "tbl_sql")
+class(remote_mtcars) <- c("tbl_sql", class(remote_mtcars))
 
 test_that("Fails when non supported arguments are passed",{
   expect_error(correlate(remote_d, y = remote_d))
@@ -12,30 +12,17 @@ test_that("Fails when non supported arguments are passed",{
   expect_error(correlate(remote_d, diagonal = 1))
 })
 
-compare_corr <- function(x, y, threshold = 0.01){
-  x$rowname <- NULL
-  y$rowname <- NULL
-  comps <- lapply(
-    1:nrow(x),
-    function(i){
-      l <- round(as.numeric(x[i, ]), 3)
-      r <- round(as.numeric(y[i, ]), 3)
-      res <- abs(l - r) > threshold
-      any(res[!is.na(res)])
-    }
-  )
-  any(as.logical(comps))
+compare_corr <- function(x, y, ...){
+  res <- purrr:::map2_lgl(x, y, ~ isTRUE(all.equal(.x[[1]], .y[[1]])), ...)
+  all(res)
 }
 
 test_that("tbl_sql routine's results are within the 0.01 threshold",{
-  expect_false(
+  expect_true(
     compare_corr(
       correlate(mtcars, quiet = TRUE),
-      correlate(remote_mtcars, quiet = TRUE)
-      )
+      correlate(remote_mtcars, quiet = TRUE),
+      tolerance = 0.01
     )
-  })
-
-
-
-
+  )
+})
