@@ -1,8 +1,8 @@
-context("Utilities") 
+context("Utilities")
 
 test_that("pair_n works", {
-  expect_is(
+  expect_s3_class(
     pair_n(1),
     "matrix"
-  )  
+  )
 })
